User Guide
==========

Welcome to the Furax user guide! This section provides comprehensive tutorials and explanations for using Furax effectively.

.. toctree::
   :maxdepth: 2

   getting_started.md
   data_structures.md
   operators.md
